@@ -21,8 +21,7 @@ class DocumentSerializer(serializers.ModelSerializer):
         read_only_fields = 'creator', 'filename', 'uploaded_at', 'project'
 
     def create(self, validated_data):
-        project = self.context['project']
-        return services.create_document(project, **validated_data)
+        return services.create_document(**validated_data)
 
     def to_representation(self, document):
         data = super().to_representation(document)
